@@ -61,10 +61,10 @@ class GeminiTranslator(SphinxTranslator):
     def add_text(self, text: str) -> None:
         if self.table:
             if len(self.cell_text):
-                self.cell_text[-1] += text
+                self.cell_text[-1] += text or ''
             else:
                 self.cell_text.append(text)
-        else:
+        elif text:
             self.body += text
 
     def add_link(self, url: str, label: str = '') -> None:
